@@ -26,8 +26,7 @@ def saveData():
     # dd=User().native("select * from user").execute()
     # dd=User().search().like("id","1").execute()
     # print dd
-    # User().update(name="Jieke").where(id=12).execute()
-    print u.search_all()
+    User().update(name="Jieke").where(id=12).execute()
 saveData()
 
 
